@@ -1,17 +1,17 @@
 /*
- * Copyright (c) Martin R. Jones 1996
- * Copyright (c) Bernd Wuebben 1998
- *
- * Copyright (c) Torben Weis 1998
- *     KControl port & modifications
- *
- * Copyright (c) David Faure 1998
- *     End of the KControl port, added 'kfmclient configure' call.
- *
- * Copyright (c) Daniel Molkentin 2000
- *     Cleanup and modifications for KDE 2.1
- *
- */
+    SPDX-FileCopyrightText: 1996 Martin R. Jones
+    SPDX-FileCopyrightText: 1998 Bernd Wuebben
+
+    SPDX-FileCopyrightText: 1998 Torben Weis
+    KControl port & modifications
+
+    SPDX-FileCopyrightText: 1998 David Faure
+    End of the KControl port, added 'kfmclient configure' call.
+
+    SPDX-FileCopyrightText: 2000 Daniel Molkentin
+    Cleanup and modifications for KDE 2.1
+
+*/
 
 #ifndef APPEARANCE_H
 #define APPEARANCE_H
