@@ -23,10 +23,12 @@
 
 // KDE
 #include <kbuildsycocaprogressdialog.h>
-#include <kmimetypetrader.h>
-#include <kservice.h>
+// #include <kmimetypetrader.h>
+// #include <kservice.h>
 #include <KConfigGroup>
 #include <KSharedConfig>
+#include <KMessageWidget>
+#include <KParts/PartLoader>
 
 // Local
 #include "ui_advancedTabOptions.h"
@@ -40,7 +42,7 @@ enum StartPage { ShowAboutPage, ShowStartUrlPage, ShowBlankPage, ShowBookmarksPa
 //-----------------------------------------------------------------------------
 
 KKonqGeneralOptions::KKonqGeneralOptions(QWidget *parent, const QVariantList &)
-    : KCModule(parent)
+    : KCModule(parent), m_emptyStartUrlWarning(new KMessageWidget(this))
 {
     m_pConfig = KSharedConfig::openConfig(QStringLiteral("konquerorrc"), KConfig::NoGlobals);
     QVBoxLayout *lay = new QVBoxLayout(this);
@@ -74,6 +76,12 @@ void KKonqGeneralOptions::addHomeUrlWidgets(QVBoxLayout *lay)
     QFormLayout *formLayout = new QFormLayout;
     lay->addLayout(formLayout);
 
+    m_emptyStartUrlWarning->setText(i18nc("The user chose to use a custom start page but left the corresponding field empty", "Please, insert the custom start page"));
+    m_emptyStartUrlWarning->setMessageType(KMessageWidget::Warning);
+    m_emptyStartUrlWarning->setIcon(QIcon::fromTheme("dialog-warning"));
+    m_emptyStartUrlWarning->hide();
+    formLayout->addRow(m_emptyStartUrlWarning);
+
     QLabel *startLabel = new QLabel(i18nc("@label:listbox", "When &Konqueror starts:"), this);
 
     QWidget *containerWidget = new QWidget(this);
@@ -94,15 +102,16 @@ void KKonqGeneralOptions::addHomeUrlWidgets(QVBoxLayout *lay)
     startURL = new QLineEdit(this);
     startURL->setWindowTitle(i18nc("@title:window", "Select Start Page"));
     hboxLayout->addWidget(startURL);
-    connect(startURL, &QLineEdit::textChanged, this, &KKonqGeneralOptions::slotChanged);
+    connect(startURL, &QLineEdit::textChanged, this, &KKonqGeneralOptions::displayEmpytStartPageWarningIfNeeded);
 
     QString startstr = i18n("This is the URL of the web page "
                            "Konqueror will show when starting.");
     startURL->setToolTip(startstr);
     connect(m_startCombo, QOverload<int>::of(&QComboBox::currentIndexChanged), this, [this](int idx) {
-            startURL->setEnabled(idx == ShowStartUrlPage);
+            startURL->setVisible(idx == ShowStartUrlPage);
+            displayEmpytStartPageWarningIfNeeded();
             });
-    startURL->setEnabled(false);
+    startURL->hide();
 
     ////
 
@@ -148,6 +157,15 @@ KKonqGeneralOptions::~KKonqGeneralOptions()
     delete tabOptions;
 }
 
+void KKonqGeneralOptions::displayEmpytStartPageWarningIfNeeded()
+{
+    if (startURL->isVisible() && startURL->text().isEmpty()) {
+        m_emptyStartUrlWarning->animatedShow();
+    } else if (m_emptyStartUrlWarning->isVisible()) {
+        m_emptyStartUrlWarning->animatedHide();
+    }
+}
+
 static StartPage urlToStartPageEnum(const QString &startUrl)
 {
     if (startUrl == QLatin1String("konq:blank")) {
@@ -195,15 +213,20 @@ void KKonqGeneralOptions::load()
     m_webEngineCombo->clear();
     // ## Well, the problem with using the trader to find the available parts, is that if a user
     // removed a part in keditfiletype text/html, it won't be in the list anymore. Oh well.
-    const KService::List partOfferList = KMimeTypeTrader::self()->query(QStringLiteral("text/html"), QStringLiteral("KParts/ReadOnlyPart"), QStringLiteral("not ('KParts/ReadWritePart' in ServiceTypes)"));
-    // Sorted list, so the first one is the preferred one, no need for a setCurrentIndex.
-    Q_FOREACH (const KService::Ptr partService, partOfferList) {
-        // We want only the HTML-capable parts, not any text/plain part (via inheritance)
-        // This is a small "private inheritance" hack, pending a more general solution
-        if (!partService->hasMimeType(QStringLiteral("text/plain"))) {
-            m_webEngineCombo->addItem(QIcon::fromTheme(partService->icon()), partService->name(),
-                                      QVariant(partService->storageId()));
-        }
+    QVector<KPluginMetaData> allParts = KParts::PartLoader::partsForMimeType(QStringLiteral("text/html"));
+    QVector<KPluginMetaData> partOfferList;
+    auto filter = [](const KPluginMetaData &md){
+        return !md.mimeTypes().contains(QStringLiteral("text/plain"));
+    };
+    std::copy_if(allParts.constBegin(), allParts.constEnd(), std::back_inserter(partOfferList), filter);
+
+    //We need to remove duplicates caused by having parts with both plugin metadata and .desktop files being returned twice by KParts::PartLoader::partsForMimeType
+    //TODO: remove this when this doesn't happen anymore (KF6?)
+    std::sort(partOfferList.begin(), partOfferList.end(), [](const KPluginMetaData &md1, const KPluginMetaData &md2){return md1.pluginId() == md2.pluginId();});
+    auto unique = std::unique(partOfferList.begin(), partOfferList.end(), [](const KPluginMetaData &md1, const KPluginMetaData &md2){return md1.pluginId() == md2.pluginId();});
+    partOfferList.erase(unique, partOfferList.end());
+    for (const KPluginMetaData &md : partOfferList) {
+        m_webEngineCombo->addItem(QIcon::fromTheme(md.iconName()), md.name(), md.pluginId());
     }
 
     KConfigGroup cg(m_pConfig, "FMSettings"); // ### what a wrong group name for these settings...
@@ -240,10 +263,11 @@ void KKonqGeneralOptions::save()
 {
     KConfigGroup userSettings(m_pConfig, "UserSettings");
     const int startComboIndex = m_startCombo->currentIndex();
-    const int choice = m_startCombo->itemData(startComboIndex).toInt();
+    const StartPage choice = static_cast<StartPage>(m_startCombo->itemData(startComboIndex).toInt());
     QString startUrl(startPageEnumToUrl(static_cast<StartPage>(choice)));
-    if (startUrl.isEmpty())
+    if (startUrl.isEmpty()) {
         startUrl = startURL->text();
+    }
     userSettings.writeEntry("StartURL", startUrl);
     userSettings.writeEntry("HomeURL", homeURL->text());
     userSettings.writeEntry("AlwaysDuplicatePageWhenSplittingView", m_splitBehaviour->currentIndex() == 0);
